summaryrefslogtreecommitdiffstats
path: root/xci/xci-deploy.sh
diff options
context:
space:
mode:
Diffstat (limited to 'xci/xci-deploy.sh')
-rwxr-xr-xxci/xci-deploy.sh10
1 files changed, 6 insertions, 4 deletions
diff --git a/xci/xci-deploy.sh b/xci/xci-deploy.sh
index 718ed73c..2ce7c6b0 100755
--- a/xci/xci-deploy.sh
+++ b/xci/xci-deploy.sh
@@ -4,11 +4,13 @@ set -o nounset
set -o pipefail
#-------------------------------------------------------------------------------
# This script must run as root
#-------------------------------------------------------------------------------
-if [[ $(whoami) != "root" ]]; then
- echo "Error: This script must be run as root!"
- exit 1
+if [[ $(whoami) == "root" ]]; then
+ echo "WARNING: This script should not be run as root!"
+ echo "Elevated privileges are aquired automatically when necessary"
+ echo "Waiting 10s to give you a chance to stop the script (Ctrl-C)"
+ for x in $(seq 10 -1 1); do echo -n "$x..."; sleep 1; done
fi
#-------------------------------------------------------------------------------
@@ -4,11 +4,13 @@ set -o nounset
set -o pipefail
#-------------------------------------------------------------------------------
-# This script must run as root
+# This script should not be run as root
#-------------------------------------------------------------------------------